==> opensubdiv-3.5.0-2-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/a00782.js <==
var a00782 =
[
    [ "MeshInterface< PATCH_TABLE >", "a01261.html", "a01261" ],
    [ "EvaluatorCacheT< EVALUATOR >", "a01265.html", "a01265" ],
    [ "EvaluatorCacheT< EVALUATOR >::Entry", "a01269.html", "a01269" ],
    [ "Mesh< VERTEX_BUFFER, STENCIL_TABLE, EVALUATOR, PATCH_TABLE, DEVICE_CONTEXT >", "a01273.html", "a01273" ],
    [ "MeshBitset", "a00782.html#a85ba9df501aea9af1ec9da1558c255bc", null ],
    [ "MeshBits", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492", [
      [ "MeshAdaptive", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492adef344bcbdd50a1a93136eb53183c718", null ],
      [ "MeshInterleaveVarying", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9313c644b9b2a998bcb55cfcc4582b1a", null ],
      [ "MeshFVarData", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ac10e41fef659f3b3a1b730319bdedb45", null ],
      [ "MeshFVarAdaptive", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9b8a23ab039e120012bc7c622308d603", null ],
      [ "MeshUseSmoothCornerPatch", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ab32b8ef595539e14041e2fb0e619e3f9", null ],
      [ "MeshUseSingleCreasePatch", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9058d69e1089fc77f1974a76c34e2071", null ],
      [ "MeshUseInfSharpPatch", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a8fab1b3018f94b5b2432c7435e795925", null ],
      [ "MeshEndCapBilinearBasis", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a4124233e4f787f999c7975afceab34f3", null ],
      [ "MeshEndCapBSplineBasis", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2f41b6ba0393698bb3af283283737f7", null ],
      [ "MeshEndCapGregoryBasis", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2878e1a215530f5f6fb89f1e06f91ee", null ],
      [ "MeshEndCapLegacyGregory", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aad7b3fb2be609abdbfafaf5b1c834158", null ],
      [ "NUM_MESH_BITS", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a5676712c77d29cfdd330e2802db1c464", null ]
    ] ],
    [ "convertToCompatibleStencilTable", "a00782.html#a06ceddf21c024b341a5b946049cd701a", null ],
    [ "convertToCompatibleStencilTable< Far::LimitStencilTable, Far::LimitStencilTable, void >", "a00782.html#a4c2520cc1a8a5a03e3f53584629d7318", null ],
    [ "convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, ID3D11DeviceContext >", "a00782.html#ab5753a2b0a0995c8e2259d2c4765f7df", null ],
    [ "convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, void >", "a00782.html#a33f9830228f847fae1c30c9dffe02b5a", null ]
];

==> opensubdiv-3.6.0-1-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/a00782.js <==
var a00782 =
[
    [ "MeshInterface< PATCH_TABLE >", "a01269.html", "a01269" ],
    [ "EvaluatorCacheT< EVALUATOR >", "a01273.html", "a01273" ],
    [ "Entry", "a01277.html", "a01277" ],
    [ "Mesh< VERTEX_BUFFER, STENCIL_TABLE, EVALUATOR, PATCH_TABLE, DEVICE_CONTEXT >", "a01281.html", "a01281" ],
    [ "MeshBitset", "a00782.html#a85ba9df501aea9af1ec9da1558c255bc", null ],
    [ "MeshBits", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492", [
      [ "MeshAdaptive", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492adef344bcbdd50a1a93136eb53183c718", null ],
      [ "MeshInterleaveVarying", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9313c644b9b2a998bcb55cfcc4582b1a", null ],
      [ "MeshFVarData", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ac10e41fef659f3b3a1b730319bdedb45", null ],
      [ "MeshFVarAdaptive", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9b8a23ab039e120012bc7c622308d603", null ],
      [ "MeshUseSmoothCornerPatch", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492ab32b8ef595539e14041e2fb0e619e3f9", null ],
      [ "MeshUseSingleCreasePatch", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a9058d69e1089fc77f1974a76c34e2071", null ],
      [ "MeshUseInfSharpPatch", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a8fab1b3018f94b5b2432c7435e795925", null ],
      [ "MeshEndCapBilinearBasis", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a4124233e4f787f999c7975afceab34f3", null ],
      [ "MeshEndCapBSplineBasis", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2f41b6ba0393698bb3af283283737f7", null ],
      [ "MeshEndCapGregoryBasis", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aa2878e1a215530f5f6fb89f1e06f91ee", null ],
      [ "MeshEndCapLegacyGregory", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492aad7b3fb2be609abdbfafaf5b1c834158", null ],
      [ "NUM_MESH_BITS", "a00782.html#a1af6b50e9f8ae13d3d2f9d5b03b35492a5676712c77d29cfdd330e2802db1c464", null ]
    ] ],
    [ "convertToCompatibleStencilTable", "a00782.html#a06ceddf21c024b341a5b946049cd701a", null ],
    [ "convertToCompatibleStencilTable< Far::LimitStencilTable, Far::LimitStencilTable, void >", "a00782.html#a4c2520cc1a8a5a03e3f53584629d7318", null ],
    [ "convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, ID3D11DeviceContext >", "a00782.html#ab5753a2b0a0995c8e2259d2c4765f7df", null ],
    [ "convertToCompatibleStencilTable< Far::StencilTable, Far::StencilTable, void >", "a00782.html#a33f9830228f847fae1c30c9dffe02b5a", null ]
];
